#!/usr/bin/env python
# -*- coding: utf-8 -*-

import FreeCAD
import Mesh
import os
import glob
#import wx
import PySide
from PySide import QtGui

#app = wx.App(0)

import pythonVerCheck
import pyDexcsSwakSubset

doc = App.ActiveDocument
name = os.path.splitext(doc.FileName)[0]
modelDir = os.path.dirname(doc.FileName)

#モデルファイル置き場がケースファイルの場所（.CaseFileDictで指定）と異なる場合
caseFileDict = modelDir + "/.CaseFileDict"
if os.path.isfile(caseFileDict) == True:
    f = open(caseFileDict)
    modelDir = f.read()
    f.close()
os.chdir(modelDir)

def getSolver():
    solver = ""
    fileName = "./system/controlDict"
    if glob.glob(fileName) != "":
        f=open("./system/controlDict")
        for line in f.readlines():
            item = line.split()
            if len(item)>0:
                if item[0] == "application":
                    solver = line.split()[1]
                    break
    return solver

def checkApp(directory, App):
    flag = "NG"
    names = glob.glob(directory + "/" + App)
    if len(names) == 1:
        flag = "OK"
    else:
        names = glob.glob(App)
        if len(names) == 1:
            flag = "OK"
        else:
            paths = os.environ["PATH"].split(":")
            for path in paths:
                names = glob.glob(path + "/" + App)
                if len(names) == 1:
                    flag = "OK"
                    break
    return flag

def errDialog(title, message):
    #dlg = wx.MessageDialog(None, message, title,
    #                        style = wx.OK | wx.ICON_HAND) 
    #dlg.ShowModal()
    #dlg.Destroy()
  diag = QtGui.QMessageBox(\
    QtGui.QMessageBox.Information,\
    title,\
    message)
  diag.exec_()

systemFolder = modelDir + "/system"
constantFolder = modelDir + "/constant"

if os.path.isdir(systemFolder) and os.path.isdir(constantFolder):

	solver = getSolver().replace(';','')

	configDict = pyDexcsSwakSubset.readConfigTreeFoam()
	envOpenFOAMFix = configDict["bashrcFOAM"]
	configDict = pyDexcsSwakSubset.readConfigDexcs()
	envTreeFoam = configDict["TreeFoam"]
	envOpenFOAMFix = envOpenFOAMFix.replace('$TreeFoamUserPath',envTreeFoam)
	envOpenFOAMFix = os.path.expanduser(envOpenFOAMFix)
	#print(envOpenFOAMFix)
	solveCaseFix = modelDir
	if checkApp(solveCaseFix, envOpenFOAMFix) == "OK":
	    #solver = getSolver(solveCaseFix)
	    if solver != "":
	    	saveDir = os.getcwd()
	    	os.chdir(solveCaseFix)
	    	logFile = "solve.log"
	    	if len(glob.glob(logFile)) == 0:
	    	    logFile = "log." + solver
	    	cont = "#!/bin/bash\n"
	    	cont = cont + ". " + envOpenFOAMFix + "\n"
	    	cont = cont + 'echo -n "running plotWatcher"\n'
	    	cont = cont + "pyFoamPlotWatcher.py " + logFile + " 1> /dev/null 2> /dev/null\n"
	    	f = open("plotWatcher", "w")
	    	f.write(cont)
	    	f.close()
	    	os.system("chmod a+x plotWatcher")
	    	title = solveCaseFix
	    	if len(title) > 30:
	    	    title = "_..." + title[-30:]
	    	title = "plotWatcher:" + title
	    	#comm = "gnome-terminal --name=" + title + " --geometry=80x2 --hide-menubar -x bash --rcfile plotWatcher"
	    	comm = "gnome-terminal --name=" + title + " --geometry=80x2 --hide-menubar -- bash --rcfile plotWatcher"
	    	os.system(comm)
	    	os.chdir(saveDir)
	    else:
	    	title = _("error")
	    	message = _("does not exist 'controlDict'.\n")
	    	message = message + _("wrong case directory.")
	    	errDialog(title, message)
	else:
	    title = _("error")
	    message = _("environ file 'bashrcFOAM' does not exist, FOAM terminal could not run.\n")
	    message = message + _("    check contents of configTreeFoam file.")
	    errDialog(title, message)

else:
    message = (_("this folder is not case folder of OpenFOAM.\n  check current directory."))
    ans = QtGui.QMessageBox.critical(None, _("check OpenFOAM case"), message, QtGui.QMessageBox.Yes)

